@@ -16,7 +16,7 @@ def parse(filename):
     if len(data) >= 2 and data[1] != "":
         metadata = yaml.load(data[1])
 
-    if len(data) >= 2:
+    if len(data) >= 3:
         content = data[2]
 
     return metadata, content
@@ -33,7 +33,7 @@ def dump(filename, metadata, content):
     yaml.dump(metadata, buf)
     buf.write(FRONTMATTER_SEPARATOR)
     if content is not None:
-        buf.write(content)
+        buf.write(content.strip())
 
     with open(filename, "w") as f:
         print(buf.getvalue(), file=f)
